@@ -9,9 +9,9 @@
 #ifndef __kparts_openurlevent_h__
 #define __kparts_openurlevent_h__
 
-#include <kparts/browserarguments.h>
-#include <kparts/event.h>
+#include <QEvent>
 #include <kparts/openurlarguments.h>
+#include <memory>
 
 class QUrl;
 
@@ -29,28 +29,20 @@ class OpenUrlEventPrivate;
  * The event should be sent before opening the URL in the part, so that the plugins
  * can use part()->url() to get the old URL.
  */
-class KPARTS_EXPORT OpenUrlEvent : public Event
+class KPARTS_EXPORT OpenUrlEvent : public QEvent
 {
 public:
-    OpenUrlEvent(ReadOnlyPart *part,
-                 const QUrl &url,
-                 const OpenUrlArguments &args = OpenUrlArguments(),
-                 const BrowserArguments &browserArgs = BrowserArguments());
+    OpenUrlEvent(ReadOnlyPart *part, const QUrl &url, const OpenUrlArguments &args = OpenUrlArguments());
     ~OpenUrlEvent() override;
 
     ReadOnlyPart *part() const;
     QUrl url() const;
     OpenUrlArguments arguments() const;
-    BrowserArguments browserArguments() const;
 
     static bool test(const QEvent *event);
 
 private:
-    Q_DECLARE_PRIVATE_D(Event::d, OpenUrlEvent)
-#if KPARTS_BUILD_DEPRECATED_SINCE(5, 79)
-    // Unused, kept for ABI compatibility
-    const void *__kparts_d_do_not_use;
-#endif
+    const std::unique_ptr<OpenUrlEventPrivate> d;
 };
 
 }
