@@ -1,38 +1,29 @@
-/* This file is part of the KDE project
-   Copyright (C) 1999 Simon Hausmann <hausmann@kde.org>
-             (C) 1999 David Faure <faure@kde.org>
+/*
+    This file is part of the KDE project
+    SPDX-FileCopyrightText: 1999 Simon Hausmann <hausmann@kde.org>
+    SPDX-FileCopyrightText: 1999 David Faure <faure@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
+
 #ifndef __kpartmanager_h__
 #define __kpartmanager_h__
 
 #include <kparts/kparts_export.h>
 
 #include <QWidget>
+#include <memory>
 
 namespace KParts
 {
-
 class Part;
 
 class PartManagerPrivate;
 
 /**
- * The part manager is an object which knows about a collection of parts
+ * @class PartManager partmanager.h <KParts/PartManager>
+ *
+ * @short The part manager is an object which knows about a collection of parts
  * (even nested ones) and handles activation/deactivation.
  *
  * Applications that want to embed parts without merging GUIs
@@ -77,7 +68,7 @@ public:
      * @param parent   The parent QObject.
      */
     PartManager(QWidget *topLevel, QObject *parent);
-    virtual ~PartManager();
+    ~PartManager() override;
 
     /**
      * Sets the selection policy of the partmanager.
@@ -123,7 +114,7 @@ public:
     /**
      * Specifies which mouse buttons the partmanager should react upon.
      * By default it reacts on all mouse buttons (LMB/MMB/RMB).
-     * @param buttonMask a combination of Qt::ButtonState values e.g. Qt::LeftButton | Qt::MidButton
+     * @param buttonMask a combination of Qt::ButtonState values e.g. Qt::LeftButton | Qt::MiddleButton
      */
     void setActivationButtonMask(short int buttonMask);
     /**
@@ -134,7 +125,7 @@ public:
     /**
      * @internal
      */
-    bool eventFilter(QObject *obj, QEvent *ev) Q_DECL_OVERRIDE;
+    bool eventFilter(QObject *obj, QEvent *ev) override;
 
     /**
      * Adds a part to the manager.
@@ -177,26 +168,6 @@ public:
      */
     virtual QWidget *activeWidget() const;
 
-    /**
-     * Sets the selected part.
-     *
-     * The selected part receives selection events.
-     *
-     * @p widget can be used to specify which widget was responsible for the selection.
-     * This is important if you have multiple views for a document/part , like in KOffice .
-     */
-    virtual void setSelectedPart(Part *part, QWidget *widget = nullptr);
-
-    /**
-     * Returns the current selected part.
-     */
-    virtual Part *selectedPart() const;
-
-    /**
-     * Returns the selected widget of the current selected part (see selectedPart ).
-     */
-    virtual QWidget *selectedWidget() const;
-
     /**
      * Returns the list of parts being managed by the partmanager.
      */
@@ -240,9 +211,8 @@ Q_SIGNALS:
     void activePartChanged(KParts::Part *newPart);
 
 protected:
-
     /**
-     * Sets whether the PartManager ignores explict set focus requests
+     * Sets whether the PartManager ignores explicit set focus requests
      * from the part.
      *
      * By default this option is set to false. Set it to true to prevent
@@ -268,15 +238,15 @@ protected Q_SLOTS:
      * @internal
      */
     void slotManagedTopLevelWidgetDestroyed();
-private:
-    Part *findPartFromWidget(QWidget *widget, const QPoint &pos);
-    Part *findPartFromWidget(QWidget *widget);
 
 private:
-    PartManagerPrivate *const d;
+    KPARTS_NO_EXPORT Part *findPartFromWidget(QWidget *widget, const QPoint &pos);
+    KPARTS_NO_EXPORT Part *findPartFromWidget(QWidget *widget);
+
+private:
+    std::unique_ptr<PartManagerPrivate> const d;
 };
 
 }
 
 #endif
-
